@@ -1,5 +1,4 @@
-from meshtool.args import *
-from meshtool.filters.base_filters import *
+from meshtool.filters.base_filters import LoadFilter, FilterException
 import collada
 import os
 
@@ -18,3 +17,5 @@ def FilterGenerator():
                 
             return col
     return ColladaLoadFilter()
+from meshtool.filters import factory
+factory.register(FilterGenerator().name, FilterGenerator)
\ No newline at end of file
