@@ -1,5 +1,4 @@
-from meshtool.args import *
-from meshtool.filters.base_filters import *
+from meshtool.filters.base_filters import OptimizationFilter
 
 def combineEffects(mesh):
     effect_sets = []
@@ -28,10 +27,12 @@ def combineEffects(mesh):
             del mesh.effects[other.id]
 
 def FilterGenerator():
-    class CombineEffectsFilter(OpFilter):
+    class CombineEffectsFilter(OptimizationFilter):
         def __init__(self):
             super(CombineEffectsFilter, self).__init__('combine_effects', 'Combines identical effects')
         def apply(self, mesh):
             combineEffects(mesh)
             return mesh
     return CombineEffectsFilter()
+from meshtool.filters import factory
+factory.register(FilterGenerator().name, FilterGenerator)
\ No newline at end of file
