@@ -1,5 +1,4 @@
-from meshtool.args import *
-from meshtool.filters.base_filters import *
+from meshtool.filters.base_filters import OptimizationFilter
 import collada
 
 def stripLines(mesh):
@@ -8,10 +7,12 @@ def stripLines(mesh):
                            if type(prim) is not collada.lineset.LineSet]
 
 def FilterGenerator():
-    class StripLinesFilter(OpFilter):
+    class StripLinesFilter(OptimizationFilter):
         def __init__(self):
             super(StripLinesFilter, self).__init__('strip_lines', 'Strips any lines from the document')
         def apply(self, mesh):
             stripLines(mesh)
             return mesh
     return StripLinesFilter()
+from meshtool.filters import factory
+factory.register(FilterGenerator().name, FilterGenerator)
\ No newline at end of file
