@@ -1,5 +1,4 @@
-from meshtool.args import *
-from meshtool.filters.base_filters import *
+from meshtool.filters.base_filters import OptimizationFilter
 import collada
 
 def triangulate(mesh):
@@ -13,10 +12,12 @@ def triangulate(mesh):
         geom.primitives = triprims
 
 def FilterGenerator():
-    class TriangulateFilter(OpFilter):
+    class TriangulateFilter(OptimizationFilter):
         def __init__(self):
             super(TriangulateFilter, self).__init__('triangulate', 'Replaces any polylist or polygons with triangles')
         def apply(self, mesh):
             triangulate(mesh)
             return mesh
     return TriangulateFilter()
+from meshtool.filters import factory
+factory.register(FilterGenerator().name, FilterGenerator)
\ No newline at end of file
