@@ -1,5 +1,4 @@
-from meshtool.args import *
-from meshtool.filters.base_filters import *
+from meshtool.filters.base_filters import SaveFilter, FilterException
 import os.path
 
 from meshtool.filters.panda_filters.pandacore import setupPandaApp, getScreenshot
@@ -20,3 +19,5 @@ def FilterGenerator():
             return mesh
         
     return SaveScreenshotFilter()
+from meshtool.filters import factory
+factory.register(FilterGenerator().name, FilterGenerator)
\ No newline at end of file
