@@ -1,5 +1,4 @@
-from meshtool.args import *
-from meshtool.filters.base_filters import *
+from meshtool.filters.base_filters import PrintFilter
 
 def getTextures(mesh):
     texs = []
@@ -8,7 +7,7 @@ def getTextures(mesh):
     return texs
 
 def FilterGenerator():
-    class PrintTexturesFilter(OpFilter):
+    class PrintTexturesFilter(PrintFilter):
         def __init__(self):
             super(PrintTexturesFilter, self).__init__('print_textures', 'Prints a list of the embedded images in the mesh')
         def apply(self, mesh):
@@ -16,3 +15,5 @@ def FilterGenerator():
                 print t
             return mesh
     return PrintTexturesFilter()
+from meshtool.filters import factory
+factory.register(FilterGenerator().name, FilterGenerator)
\ No newline at end of file
