@@ -1,5 +1,4 @@
-from meshtool.args import *
-from meshtool.filters.base_filters import *
+from meshtool.filters.base_filters import SaveFilter, FilterException
 import os
 
 def FilterGenerator():
@@ -12,3 +11,5 @@ def FilterGenerator():
             mesh.write(filename)
             return mesh
     return ColladaSaveFilter()
+from meshtool.filters import factory
+factory.register(FilterGenerator().name, FilterGenerator)
\ No newline at end of file
